@@ -10,15 +10,14 @@ The search dialog is a very high level GUI element of the qtalchemy library.  It
 the DomainEntity to provide descriptive details of the objects to query in these search dialogs.
 """
 
-from PyQtHelpers import *
-from sqlalchemy.orm import mapper, create_session, relation, object_session
-import sqlalchemy.sql.expression as expr
-from sqlalchemy_helper import *
 import sqlalchemy
+import sqlalchemy.sql.expression as expr
+from sqlalchemy.orm import mapper, create_session, relation, object_session
+from .PyQtHelpers import *
+from .sqlalchemy_helper import *
+from .PyQtModels import *
+from .commands import Command, BoundCommandMenu
 from qtalchemy.widgets import TableView
-from PyQtModels import *
-
-from commands import Command, BoundCommandMenu
 
 class PBSearchableListDialog(QtGui.QDialog):
     """
