@@ -46,8 +46,8 @@ def fromQType(v, suggested=None):
     in a native python type.
     
     (Basic) Examples:
-    >>> type(fromQType(toQType(45)))
-    <type 'int'>
+    >>> type(fromQType(toQType(45))).__name__
+    'int'
     >>> fromQType(toQType(datetime.date.today()))==datetime.date.today()
     True
     """
@@ -103,10 +103,10 @@ def toQType(v, suggested=None, empty_zero=False):
     thing.
     
     Examples:
-    >>> type(toQType(12))
-    <type 'int'>
-    >>> type(toQType("A string"))
-    <type 'str'>
+    >>> type(toQType(12)).__name__
+    'int'
+    >>> type(toQType("A string")).__name__
+    'str'
     >>> toQType(decimal.Decimal("12.34"))
     '12.34'
     >>> type(toQType(datetime.date(1979,1,9))) is QtCore.QDate
@@ -542,6 +542,24 @@ def message_excepthook(type, value, tb):
         import sys
         traceback.print_exception(type, value, tb, limit=None, file=sys.stderr)
 
+def qtGetSaveFileName(parent, title, filter):
+    if QtCore.__name__.split('.')[0] == 'PySide':
+        filename, filter = QtGui.QFileDialog.getSaveFileName(parent, title, filter=filter)
+    else:
+        filename = QtGui.QFileDialog.getSaveFileName(parent, title, filter=filter)
+    if filename == '':
+        return None
+    return filename
+
+def qtGetOpenFileName(parent, title, filter):
+    if QtCore.__name__.split('.')[0] == 'PySide':
+        filename, filter = QtGui.QFileDialog.getOpenFileName(parent, title, filter=filter)
+    else:
+        filename = QtGui.QFileDialog.getOpenFileName(parent, title, filter=filter)
+    if filename == '':
+        return None
+    return filename
+
 
 _test_app = None
 
