@@ -12,22 +12,22 @@ for foreign keys).  This requires tying in sqlalchemy data sources and makes som
 about the qtalchemy approach to building a dialog.
 """
 
-from PyQtHelpers import *
-from sqlalchemy.orm import mapper, create_session, relation, object_session, Query
-from sqlalchemy.exc import InvalidRequestError
-from sqlalchemy_helper import *
-import sqlalchemy
 import datetime
 import decimal
-from user_attr import UserAttr, AttrNumeric
+import sqlalchemy
+from sqlalchemy.orm import mapper, create_session, relation, object_session, Query
+from sqlalchemy.exc import InvalidRequestError
+from .PyQtHelpers import *
+from .sqlalchemy_helper import *
+from .user_attr import UserAttr, AttrNumeric
 
 if sqlalchemy.__version__.split('.') < ['0', '6', '0']:
-    sqlalchemy_to_python_type = [(satype,pytype) for pytype,satype in sqlalchemy.types.type_map.iteritems()]
+    sqlalchemy_to_python_type = [(satype,pytype) for pytype,satype in sqlalchemy.types.type_map.items()]
 elif sqlalchemy.__version__.split('.') < ['0', '7', '0']:
-    sqlalchemy_to_python_type = [(satype.__class__,pytype) for pytype,satype in sqlalchemy.types.type_map.iteritems()]
+    sqlalchemy_to_python_type = [(satype.__class__,pytype) for pytype,satype in sqlalchemy.types.type_map.items()]
 else:
     # TODO:  if we weren't convinced before that type_map was a secret, now we should be :)
-    sqlalchemy_to_python_type = [(satype.__class__,pytype) for pytype,satype in sqlalchemy.types._type_map.iteritems()]
+    sqlalchemy_to_python_type = [(satype.__class__,pytype) for pytype,satype in sqlalchemy.types._type_map.items()]
 sqlalchemy_to_python_type.append((sqlalchemy.types.String,str))
 
 def SA2PY(satype):
@@ -71,7 +71,7 @@ def BoundPropertyAttribute(classMember, attribute, SA2R=None, PY2R=None):
     # classMember appears like a SA column
     if hasattr(classMember,"label") and callable(classMember.label):
         col = classMember.property.columns[0]
-        if hasattr(col,"info") and col.info.has_key(attribute):
+        if hasattr(col,"info") and attribute in col.info:
             return col.info[attribute]
         else:
             if SA2R is not None:
@@ -173,7 +173,7 @@ def UserLabel(identifier):
     >>> UserLabel("account")
     'Account'
     """
-    return identifier.replace('_', ' ').title()
+    return str(identifier.replace('_', ' ').title())
 
 def ClassAttributeLabel(classMember):
     """
@@ -203,7 +203,7 @@ def ClassAttributeLabel(classMember):
     # classMember appears like a SA column
     if hasattr(classMember,"label") and callable(classMember.label):
         col=classMember.property.columns[0]
-        if hasattr(col,"info") and col.info.has_key("label"):
+        if hasattr(col,"info") and "label" in col.info:
             return col.info["label"]
         else:
             return UserLabel(col.name)
@@ -292,20 +292,20 @@ def ClassAttributeYoke(classMember):
         y = classMember.yoke_specifier()
         if y is not None:
             return y
-    except AttributeError, e:
+    except AttributeError as e:
         pass
 
     if type_ is not None:
         try:
             # specified UserAttr class?
             return type_.yoke_specifier()
-        except AttributeError, e:
+        except AttributeError as e:
             pass
 
     # classMember appears like a SA column
     if type_ is None and hasattr(classMember,"label") and callable(classMember.label):
         col=classMember.property.columns[0]
-        if hasattr(col,"info") and col.info.has_key("yoke"):
+        if hasattr(col,"info") and "yoke" in col.info:
             return col.info["yoke"]
         else:
             if isinstance(classMember.property.columns[0].type, sqlalchemy.types.Text):
@@ -370,8 +370,8 @@ def ClassAttributeType(classMember):
     
     >>> class X:
     ...     name=UserAttr(str,"First Name")
-    >>> ClassAttributeType(X.name)
-    <type 'str'>
+    >>> ClassAttributeType(X.name).__name__
+    'str'
 
     >>> from sqlalchemy import Table, Column, Integer, String, Text, Date, Boolean, Numeric, MetaData
     >>> from sqlalchemy.ext.declarative import declarative_base
@@ -386,17 +386,17 @@ def ClassAttributeType(classMember):
     ...             Column('juvenile', Boolean),
     ...             Column('price', Numeric(precision=10,scale=2,asdecimal=True)),
     ...             Column('title', String(50)))
-    >>> ClassAttributeType(Books.author)
-    <type 'str'>
-    >>> ClassAttributeType(Books.release)
-    <type 'datetime.date'>
-    >>> ClassAttributeType(Books.copies)
-    <type 'int'>
+    >>> ClassAttributeType(Books.author).__name__
+    'str'
+    >>> ClassAttributeType(Books.release).__name__
+    'date'
+    >>> ClassAttributeType(Books.copies).__name__
+    'int'
     >>> # platform confusion on the next one
     >>> ClassAttributeType(Books.price) in (decimal.Decimal, float)
     True
-    >>> ClassAttributeType(Books.juvenile)
-    <type 'bool'>
+    >>> ClassAttributeType(Books.juvenile).__name__
+    'bool'
     """
     try:
         # cls has an attribute col that looks like a UserAttr
@@ -424,8 +424,8 @@ def attrType(cls, col):
      - cls is None and col is a :class:`ModelColumn` object
     
     >>> m=ModelColumn("name",str,"First Name")
-    >>> attrType(None,m)
-    <type 'str'>
+    >>> attrType(None,m).__name__
+    'str'
     """
     try:
         # col looks like a ModelColumn
@@ -466,7 +466,7 @@ class AlchemyModelDelegate(QtGui.QStyledItemDelegate):
                 userattr = getattr(cls,c.attr if hasattr(c,"attr") else c)
                 if userattr is not None and hasattr(userattr,"WidgetBind"):
                     userattr.WidgetBind(editor,index.model().row_object_by_index(index))
-        except AttributeError, e:
+        except AttributeError as e:
             pass
 
         # http://bugreports.qt.nokia.com/browse/QTBUG-428 - combo boxes don't play nice with qdatawidget mapper 
@@ -495,7 +495,7 @@ class AlchemyModelDelegate(QtGui.QStyledItemDelegate):
                 userattr = getattr(cls,c.attr if hasattr(c,"attr") else c)
                 if userattr is not None and hasattr(userattr,"WidgetFactory"):
                     return userattr.WidgetFactory(parent, index)
-        except AttributeError, e:
+        except AttributeError as e:
             pass
         return QtGui.QStyledItemDelegate.createEditor(self,parent,option,index)
 
@@ -1089,12 +1089,12 @@ class PBTableModel(QtCore.QAbstractItemModel):
     def dropMimeData(self, data, action, row, column, parent):
         x = False
         for type in data.formats():
-            if self.dropCallable.has_key(type):
+            if type in self.dropCallable:
                 x = self.dropCallable[type](data, action, row, column, parent)
         return x
 
     def mimeTypes(self):
-        return self.dropCallable.keys() + ["text/plain"]
+        return list(self.dropCallable.keys()) + ["text/plain"]
 
     def mimeData(self, indexes):
         result = modelMimeRectangle(self, indexes)
@@ -1145,7 +1145,11 @@ def modelMimeRectangle(model, selected):
         for y in rows:
             my_indexes = [x[2] for x in sortable_index_list if x[0] == y]
             textrows.append('\t'.join(row_data(cols, my_indexes)))
-    m.setData("text/plain",'\n'.join(textrows))
+    # I would read the documentation on setText to do exactly what the setData
+    # line does.  However, that doesn't seem to be the case.  I prefer the
+    # setData as it seems more fundamental, but maybe that is just silly.
+    #m.setData("text/plain",'\n'.join(textrows))
+    m.setText('\n'.join(textrows))
     return m
 
 
@@ -1266,7 +1270,7 @@ class WidgetAttributeMapper(object):
          - None, '':  no label and edit widget in cell (row,column)
         :param rowSpan:  The span of 
         """
-        import input_yoke
+        from . import input_yoke
 
         y = input_yoke.YokeFactory(self.cls,attr, self)
         self.yokes.append(y)
@@ -1293,7 +1297,7 @@ class WidgetAttributeMapper(object):
         """
         Adds a labeled field to a layout.
         """
-        import input_yoke
+        from . import input_yoke
 
         y = input_yoke.YokeFactory(self.cls,attr, self)
         self.yokes.append(y)
@@ -1325,7 +1329,7 @@ class WidgetAttributeMapper(object):
                 y.Save()
 
     def bind(self, widget, attr, yoke_factory=None):
-        import input_yoke
+        from . import input_yoke
 
         if yoke_factory is None:
             y = input_yoke.YokeFactory(self.cls, attr, self)
