@@ -13,21 +13,22 @@ sqlalchemy and PyQt/PySide.
 # TODO:  Review for best use of our global namespace to highlight the correct 
 # way to do things.
 
-from PyQtHelpers import LayoutWidget, LayoutLayout, ButtonBoxButton, FormRow, \
+from .PyQtHelpers import LayoutWidget, LayoutLayout, ButtonBoxButton, FormRow, \
             WindowGeometry, OnlineHelp, \
             writeTableColumnGeo, readTableColumnGeo, suffixExtId, \
             fromQType, toQType, qtapp, message_excepthook, \
+            qtGetSaveFileName, qtGetOpenFileName, \
             Signal, Slot, Property
 
-from commands import DomainEntity, Command, CommandMenu, CommandEvent, \
+from .commands import DomainEntity, Command, CommandMenu, CommandEvent, \
         BoundCommandMenu, BoundCommandMenuItem
 
-from user_attr import hasextendedattr, getextendedattr, setextendedattr, \
+from .user_attr import hasextendedattr, getextendedattr, setextendedattr, \
         UserAttr, Nullable, AttrNumeric, UseCachedValue
-from sqlalchemy_helper import ModelObject, ModelSession, PBSessionMaker, UUID, \
+from .sqlalchemy_helper import ModelObject, ModelSession, PBSessionMaker, UUID, \
         ValidationError, user_message, Message, instanceEvent, sessionExtension
 
-from input_yoke import \
+from .input_yoke import \
     addGlobalYoke, \
     InputYoke, \
     LineYoke, \
@@ -38,18 +39,18 @@ from input_yoke import \
     FloatingPointYoke
 
 # model elements
-from PyQtModels import ClassTableModel, QueryTableModel, QueryClassTableModel, \
+from .PyQtModels import ClassTableModel, QueryTableModel, QueryClassTableModel, \
         ModelColumn, PBTableModel, AlchemyModelDelegate, modelMimeRectangle, \
         MapperMixin, WidgetAttributeMapper, ObjectRepresent, \
         attrLabel, ClassAttributeLabel, attrType, ClassAttributeType, attrReadonly
 
-from foreign_key import ForeignKeyReferral, ForeignKeyEditYoke, ForeignKeyComboYoke
+from .foreign_key import ForeignKeyReferral, ForeignKeyEditYoke, ForeignKeyComboYoke
 
 # TODO:  Some more of these should be moved to the widgets sub-module
 # gui elements
-from PBSearchDialog import PBSearchDialog, PBTableTab, PBMdiTableView
+from .PBSearchDialog import PBSearchDialog, PBTableTab, PBMdiTableView
 
-import icons_rc
+from . import icons_rc
 
-__version_info__ = ['0', '8', '2']
+__version_info__ = ['0', '8', '3']
 __version__ = '.'.join(__version_info__)
