@@ -14,7 +14,7 @@ and sorting the commands for global application consistency.
 
 import weakref
 import inspect
-from PyQtHelpers import *
+from .PyQtHelpers import *
 from PySide import QtCore, QtGui
 
 DROP_ACTION_TYPE="drop-action"
@@ -56,7 +56,7 @@ class Command(object):
         return func
 
     def name(self):
-        return self.func.func_name
+        return self.func.__name__
 
     def action(self, parent):
         # drag & drop operations are not prompted by QAction gui events (and they must come with mime data)
@@ -81,7 +81,7 @@ class Command(object):
         action_map = {"new": 2, "view": 4, "action": 6, "delete": 8}
         try:
             actInt = action_map[self.command_type]
-        except KeyError, e:
+        except KeyError as e:
             actInt = 5
         return "{0:01f}{1:03f}".format(actInt, self.sort)
 
@@ -141,13 +141,13 @@ class CommandMenu(object):
         #.  identifier or object acted on.  This should have a default of 
             None if requireSelection is not specified in itemNew.
         """
-        if not kwargs.has_key("descr"):
+        if "descr" not in kwargs:
             kwargs["descr"] = "&New..."
-        if not kwargs.has_key("iconFile"):
+        if "iconFile" not in kwargs:
             kwargs["iconFile"] = ":/qtalchemy/default-new.ico"
-        if not kwargs.has_key("requireSelection"):
+        if "requireSelection" not in kwargs:
             kwargs["requireSelection"] = False
-        if not kwargs.has_key("viewRelated"):
+        if "viewRelated" not in kwargs:
             kwargs["viewRelated"] = True
         kwargs["type"] = "new"
         return self.command(**kwargs)
@@ -163,13 +163,13 @@ class CommandMenu(object):
         #.  identifier or object acted on.  This should have a default of 
             None if requireSelection is not specified in itemNew.
         """
-        if not kwargs.has_key("descr"):
+        if "descr" not in kwargs:
             kwargs["descr"] = "&Delete..."
-        if not kwargs.has_key("requireSelection"):
+        if "requireSelection" not in kwargs:
             kwargs["requireSelection"] = True
-        if not kwargs.has_key("viewRelated"):
+        if "viewRelated" not in kwargs:
             kwargs["viewRelated"] = True
-        if not kwargs.has_key("iconFile"):
+        if "iconFile" not in kwargs:
             kwargs["iconFile"] = ":/qtalchemy/default-delete.ico"
         kwargs["type"] = "delete"
         return self.command(**kwargs)
@@ -185,9 +185,9 @@ class CommandMenu(object):
         #.  identifier or object acted on.  This should have a default of 
             None if requireSelection is not specified in itemNew.
         """
-        if not kwargs.has_key("requireSelection"):
+        if "requireSelection" not in kwargs:
             kwargs["requireSelection"] = True
-        if not kwargs.has_key("viewRelated"):
+        if "viewRelated" not in kwargs:
             kwargs["viewRelated"] = True
         kwargs["type"] = "action"
         return self.command(descr, **kwargs)
@@ -198,7 +198,7 @@ class CommandMenu(object):
         to the row.  This is typically used with-in the context of a 
         QAbstractItemView derived widget.
         """
-        if not kwargs.has_key("requireSelection"):
+        if "requireSelection" not in kwargs:
             kwargs["requireSelection"] = True
         kwargs["viewRelated"] = True
         kwargs["type"] = DROP_ACTION_TYPE
