@@ -7,8 +7,8 @@
 ##############################################################################
 from qtalchemy import *
 from PySide import QtCore, QtGui
-from auth_settings import AuthSettings
-from objectforms import MapperDialog, exception_message_box
+from .auth_settings import AuthSettings
+from .objectforms import MapperDialog, exception_message_box
 
 class LoginDialog(MapperDialog):
     """
@@ -76,7 +76,7 @@ class LoginDialog(MapperDialog):
                 self.init_session_maker(self.connection)
             
             super(LoginDialog,self).accept()
-        except Exception, e:
+        except Exception as e:
             exception_message_box(e,"There was an error initializing the data.",icon=QtGui.QMessageBox.Warning)
 
 def auth_dialog(parent=None,init_session_maker=None,init_db=None):
