@@ -84,7 +84,7 @@ def messaged_commit(session, parent):
     """
     try:
         session.commit()
-    except Exception, e:
+    except Exception as e:
         exception_message_box(e,"There was an error saving the data.",parent=parent,icon=QtGui.QMessageBox.Warning)
 
 class MapperDialog(QtGui.QDialog, MapperMixin):
@@ -202,7 +202,7 @@ class BoundDialog(MapperDialog):
             if self.flush_on_close:
                 self.flush()
                 self.session.close()
-        except Exception, e:
+        except Exception as e:
             self.session.rollback()
             exception_message_box(e,"There was an error saving data.",icon=QtGui.QMessageBox.Warning,parent=self)
             event.abort()
