@@ -11,7 +11,7 @@ uses a session-maker object and a class and imports data from a file or
 by raw tabular entry.
 """
 
-from wizard import ImportWizard, \
+from .wizard import ImportWizard, \
     ImportDataSource, \
     ImportDataPreview, \
     ImportIntroPage
