@@ -16,13 +16,6 @@ import decimal
 import datetime
 import fuzzyparsers
 
-def qtGetOpenFileName(parent, title, filter):
-    if QtCore.__name__.split('.')[0] == 'PySide':
-        fileName, filter = QtGui.QFileDialog.getOpenFileName(parent, title, filter=filter)
-    else:
-        fileName = QtGui.QFileDialog.getOpenFileName(parent, title, filter=filter)
-    return fileName
-
 class ImportColumn(ModelObject):
     def __init__(self, identifier, label):
         self.identifier = identifier
@@ -82,7 +75,7 @@ class ImportDataSource(QtGui.QWizardPage):
 
     def import_browse(self):
         fileName = qtGetOpenFileName(self,"Data for Import",filter="Comma Separated Values (*.csv);;All Files (*.*)")
-        if fileName != "":
+        if fileName != None:
             self.fileEdit.setText(fileName)
             self.completeChanged.emit()
 
