@@ -2,13 +2,13 @@
 ##############################################################################
 #       Copyright (C) 2010, Joel B. Mohler <joel@kiwistrawberry.us>
 #
-#  Distributed under the terms of the GNU General Public License (GPL)
+#  Distributed under the terms of the GNU Lesser General Public License (LGPL)
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 
 from qtalchemy import *
 from qtalchemy.widgets import *
-from PyQt4 import QtCore, QtGui
+from PySide import QtCore, QtGui
 from sqlalchemy.orm import Query
 import sqlalchemy.sql.expression as expr
 
@@ -115,7 +115,7 @@ class QueryDataView(QtGui.QWidget):
     >>> 
     >>> from qtalchemy import *
     >>> from qtalchemy.ext.dataviews import *
-    >>> from PyQt4 import QtCore, QtGui
+    >>> from PySide import QtCore, QtGui
     >>> 
     >>> metadata = MetaData()
     >>> Base = declarative_base(metadata=metadata, cls=ModelObject)
