@@ -45,12 +45,20 @@ def ReportLabSize(str_pagesize):
         mySize = getattr(pagesizes,mod.lower())(mySize)
     return mySize
 
+import re
+def thousands(x, sep=',', dot='.'):
+    num, _, frac = str(x).partition(dot)
+    num = re.sub(r'(\d{3})(?=\d)', r'\1'+sep, num[::-1])[::-1]
+    if frac:
+        num += dot + frac
+    return num
+
 def SuppressedZero(attr):
     def format(x):
         if x == 0:
             return ""
         else:
-            return AttrNumeric(2)(x)
+            return thousands(AttrNumeric(2)(x))
 
     return lambda instance: format(getextendedattr(instance, attr))
 sz = SuppressedZero
