@@ -6,12 +6,12 @@
 #                  http://www.gnu.org/licenses/
 ##############################################################################
 
-from qtalchemy.widgets import PBKeyEdit
-from user_attr import UserAttr
 from PySide import QtCore, QtGui
 from sqlalchemy.orm import mapper, create_session, relation, object_session, Query
-from PyQtModels import QueryTableModel, attrReadonly
-from input_yoke import InputYoke
+from .user_attr import UserAttr
+from .PyQtModels import QueryTableModel, attrReadonly
+from .input_yoke import InputYoke
+from qtalchemy.widgets import PBKeyEdit
 
 class PopupKeyListing(PBKeyEdit):
     def __init__(self, parent, Session, foreignAttr):
@@ -143,7 +143,6 @@ class ForeignKeyReferral(UserAttr):
             # QCompleter
             setattr(row,self.backref,s.query(self.class_).filter(getattr(self.class_,self.userkey).ilike(value)).one())
         except Exception as e:
-            print e
             setattr(row,self.backref,None)
 
     def keyCol(self):
@@ -200,8 +199,8 @@ class ForeignKeyReferral(UserAttr):
         except:
             pass
 
-        import PBSearchDialog
-        srch = PBSearchDialog.PBSearchDialog(Session, self.entityCls, widget.parent())
+        from .PBSearchDialog import PBSearchDialog
+        srch = PBSearchDialog(Session, self.entityCls, widget.parent())
         srch.setWindowModality(QtCore.Qt.ApplicationModal)
         srch.show()
         srch.exec_()
@@ -213,7 +212,6 @@ class ForeignKeyReferral(UserAttr):
             # we set the data internally
             setattr(row, self.backref, result)
             #setattr(row, self.backref, srch.selected_id)
-            #print "Selected item:  {0}\n".format(self.fget(row))
 
             if index is None:
                 # We are not a widget associated with an abstract item view and
@@ -261,8 +259,8 @@ class ForeignKeyEditYoke(InputYoke):
         except:
             pass
 
-        import PBSearchDialog
-        srch = PBSearchDialog.PBSearchDialog(Session, user_attr.entityCls, self.widget.parent())
+        from . import PBSearchDialog
+        srch = PBSearchDialog(Session, user_attr.entityCls, self.widget.parent())
         srch.setWindowModality(QtCore.Qt.ApplicationModal)
         srch.show()
         srch.exec_()
@@ -270,7 +268,6 @@ class ForeignKeyEditYoke(InputYoke):
         if result is not None:
             setattr(row, user_attr.backref, result)
             #setattr(row, self.backref, srch.selected_id)
-            #print "Selected item:  {0}\n".format(self.fget(row))
 
             if index is None:
                 # We are not a widget associated with an abstract item view and
@@ -361,19 +358,14 @@ class ForeignKeyValidator(QtGui.QValidator):
         self.session = session
 
     def fixup(self,input):
-        print "f"
         like_me = self.session.query(self.fkr.header_name).filter(self.fkr.header_name.ilike(str(input))).all()
         if len(like_me) == 1:
-            print QtCore.QString(like_me[0].vid)
             input.replace(0,6,QtCore.QString(like_me[0].vid))
-            print input, type(input)
         #return str(input)
 
     def validate(self,input,pos):
-        print "v"
         try:
             like_me = self.session.query(self.fkr.header_name).filter(self.fkr.header_name.ilike(str(input))).one()
-            print "v2"
             input.replace(0,6,QtCore.QString(like_me[0].vid))
             return QtGui.QValidator.Acceptable,pos
         except:
