@@ -15,7 +15,8 @@ The yokes work with a mapper object which holds the object whose attributes
 are being edited.
 """
 
-from PyQtModels import *
+from .PyQtModels import *
+from .PyQtHelpers import *
 
 class InputYoke(object):
     """
@@ -202,6 +203,7 @@ class BlankIntValidator(QtGui.QIntValidator):
 class IntegerYoke(LineYoke):
     def Factory(self):
         self.widget = QtGui.QLineEdit()
+        self.widget.setMaximumWidth(10*10)
         self._baseAdoptWidget(self.widget)
         self.widget.setValidator(BlankIntValidator())
         self.widget.editingFinished.connect(self.Save)
@@ -233,6 +235,7 @@ class BlankFloatValidator(QtGui.QDoubleValidator):
 class FloatingPointYoke(LineYoke):
     def Factory(self):
         self.widget = QtGui.QLineEdit()
+        self.widget.setMaximumWidth(12*10)
         self._baseAdoptWidget(self.widget)
         self.widget.setValidator(BlankFloatValidator(self.widget))
         self.widget.editingFinished.connect(self.Save)
@@ -325,6 +328,38 @@ class FormattedYoke(InputYoke):
         else:
             raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
 
+class CodeYoke(InputYoke):
+    def __init__(self,mapper,attr):
+        InputYoke.__init__(self,mapper)
+        self.attr = attr
+        mapper.reverse_yoke(attr,self)
+
+    def Factory(self):
+        self.widget = QtGui.QPlainTextEdit()
+        self.widget.setFont(QtGui.QFont('Courier', 10))
+        self.widget.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+        self._baseAdoptWidget(self.widget)
+        # TODO:  figure out which signals to hook to Save
+        # Qt QDataWidgetMapper uses installEventFilter
+        if hasattr(self.widget, "setReadOnly") and attrReadonly(self.mapper.cls, self.attr):
+            self.widget.setReadOnly(True)
+        return self.widget
+
+    def Bind(self):
+        if isinstance(self.widget, QtGui.QPlainTextEdit):
+            self.widget.setPlainText(self.mapper.getObjectAttr(self.attr))
+        else:
+            raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
+
+    def Save(self):
+        if self._save_dirty_blowout():
+            return
+
+        if isinstance(self.widget, QtGui.QPlainTextEdit):
+            self.mapper.setObjectAttr(self.attr,self.widget.toPlainText())
+        else:
+            raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
+
 class DateYoke(LineYoke):
     def __init__(self,mapper,attr):
         InputYoke.__init__(self,mapper)
@@ -332,7 +367,7 @@ class DateYoke(LineYoke):
         mapper.reverse_yoke(attr,self)
 
     def Factory(self):
-        from widgets import PBDateEdit
+        from .widgets import PBDateEdit
         self.widget = PBDateEdit()
         self._baseAdoptWidget(self.widget)
         self.widget.editingFinished.connect(self.Save)
@@ -458,8 +493,8 @@ class BooleanRadioYoke(InputYoke):
             self.group.addButton(self.true_radio)
             self.group.addButton(self.false_radio)
 
-        self.true_radio.clicked.connect(lambda clicked, value=True: self.radioChange(value, clicked))
-        self.false_radio.clicked.connect(lambda clicked, value=False: self.radioChange(value, clicked))
+        self.true_radio.toggled.connect(lambda checked, value=True: self.radioChange(value, checked))
+        self.false_radio.toggled.connect(lambda checked, value=False: self.radioChange(value, checked))
         for w in [self.true_radio, self.false_radio]:
             self._baseAdoptWidget(w)
 
@@ -488,6 +523,60 @@ class BooleanRadioYoke(InputYoke):
     def LabelStyle(self):
         return InputYoke.Label.Internal
 
+class ImageYoke(InputYoke):
+    def __init__(self,mapper,attr):
+        InputYoke.__init__(self,mapper)
+        self.attr = attr
+        mapper.reverse_yoke(attr,self)
+
+    def _baseAdoptWidget(self, widget):
+        widget.setMaximumSize(250, 200)
+        widget.setFrameShape(QtGui.QFrame.StyledPanel)
+        widget.setScaledContents(True)
+
+        if not attrReadonly(self.mapper.cls, self.attr):
+            # set up context menu for setting the image
+            widget.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
+            self.action_set_image = QtGui.QAction('Assign &Image...', widget)
+            self.action_set_image.triggered.connect(self.assign_image)
+            widget.addAction(self.action_set_image)
+
+    def assign_image(self):
+        filename = qtGetOpenFileName(self.widget.window(), 'Select Image', 'Images (*.png *.jpg)')
+        if filename != None:
+            self.mapper.setObjectAttr(self.attr, open(filename, 'rb').read())
+            self.Bind()
+
+    def Factory(self):
+        self.widget = QtGui.QLabel()
+        self.widget.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+        self._baseAdoptWidget(self.widget)
+        return self.widget
+
+    def Bind(self):
+        if isinstance(self.widget, QtGui.QLabel):
+            value = self.mapper.getObjectAttr(self.attr)
+            pixmap = None
+            if value == None or len(value) == 0:
+                pixmap = QtGui.QPixmap(250, 200)
+                pixmap.fill()
+            else:
+                try:
+                    pixmap = QtGui.QPixmap.fromImage(
+                                        QtGui.QImage.fromData(
+                                            self.mapper.getObjectAttr(self.attr)))
+                except Exception as e:
+                    self.widget.setText('Corrupt Image ({})'.format(str(e)))
+            if pixmap != None:
+                self.widget.setPixmap(pixmap)
+        else:
+            raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
+
+    def Save(self):
+        # save happens in realtime on events
+        pass
+
+
 def yokes_dict():
     d = {}
     d["date"] = DateYoke
@@ -497,14 +586,16 @@ def yokes_dict():
     d["int"] = IntegerYoke
     d["float"] = FloatingPointYoke
     d["text"] = TextYoke
+    d["code"] = CodeYoke
     d["formatted"] = FormattedYoke
     d["line"] = LineYoke
     d["password"] = PasswordYoke
+    d["image"] = ImageYoke
 
-    from widgets import StreetAddressYoke
+    from .widgets import StreetAddressYoke
     d["address"] = StreetAddressYoke
 
-    import foreign_key
+    from . import foreign_key
     d["foreign_key"] = foreign_key.ForeignKeyEditYoke
     d["foreign_key_edit"] = foreign_key.ForeignKeyEditYoke
     d["foreign_key_combo"] = foreign_key.ForeignKeyComboYoke
