@@ -158,15 +158,15 @@ def PBSessionMaker(**kwargs):
     The parameters are the same as sqlalchemy.orm.sessionmaker.
     """
     # We're a gui framework we want to write on dialog ok.
-    if not kwargs.has_key("autoflush"):
+    if "autoflush" not in kwargs:
         kwargs["autoflush"] = False
     # We want failed commits (due to pre-save validation) in a bound dialog to
     # live on for the second try.
-    if not kwargs.has_key("expire_on_commit"):
+    if "expire_on_commit" not in kwargs:
         kwargs["expire_on_commit"] = False
     # When you get a server side commit failure this flag keeps sqlalchemy from
     # expiring my session items.
-    if not kwargs.has_key("_enable_transaction_accounting"):
+    if "_enable_transaction_accounting" not in kwargs:
         kwargs["_enable_transaction_accounting"] = False
     # Pass it on to sqlalchemy sessionmaker, but here we have a dilemma since
     # sessionmaker changed character from the 0.7.x series to the 0.8.x series
@@ -264,7 +264,7 @@ class ModelInstrumentation(object):
         
     def event_list(self, event, attribute=None):
         if attribute is None:
-            if self.events.has_key(event):
+            if event in self.events:
                 return self.events[event]
             else:
                 return []
@@ -279,7 +279,7 @@ class ModelInstrumentation(object):
 
         if attribute is not None:
             event = "{0}.{1}".format(event, attribute)
-        if self.events.has_key(event):
+        if event in self.events:
             self.events[event].append(listener)
         else:
             self.events[event] = [listener]
@@ -387,7 +387,7 @@ class ModelObject(object):
             except KeyError as e:
                 oldvalue = None
             inst = targetInstrumentation(self)
-            if not inst.setting.has_key(attr):
+            if attr not in inst.setting:
                 inst.setting[attr] = 0
             assert 0 == inst.setting[attr], "Recursive set of {0}".format(attr)
             inst.setting[attr] += 1
@@ -415,7 +415,7 @@ class ModelObject(object):
         attribute is currently being assigned.
         """
         inst = targetInstrumentation(self)
-        return inst.setting.has_key(attr) and inst.setting[attr] > 0
+        return attr in inst.setting and inst.setting[attr] > 0
 
 class ValidationError(Exception):
     """
