@@ -41,7 +41,7 @@ class IntegerProperties(ModelObject):
         result = False
         if self.specimen >= 2:
             result = True
-            for i in xrange(2, self.specimen):
+            for i in range(2, self.specimen):
                 if i * i > self.specimen:
                     break
                 if (self.specimen % i) == 0:
