@@ -4,7 +4,7 @@ We create models, attach to data and see if the events all propogate.
 """
 
 from qtalchemy import *
-from PyQt4 import QtCore, QtGui
+from PySide import QtCore, QtGui
 
 class ItemEntity(object):
     contextMenu = CommandMenu("_context_menu")
