@@ -4,7 +4,7 @@ We create models, attach to data and see if the events all propogate.
 """
 
 from qtalchemy import UserAttr, AttrNumeric, ClassTableModel, ModelObject
-from PyQt4 import QtCore, QtGui
+from PySide import QtCore, QtGui
 
 class ItemTest(ModelObject):
     def __init__(self,item=""):
