@@ -140,10 +140,10 @@ class UserAttr(property):
         >>> fred.married = 4
         >>> (fred.name, fred.age, fred.married)
         ('Fred Jackson', 1234, True)
-        >>> type(fred.age)
-        <type 'int'>
-        >>> type(fred.married)
-        <type 'bool'>
+        >>> type(fred.age).__name__
+        'int'
+        >>> type(fred.married).__name__
+        'bool'
 
         >>> jane = Person()
         >>> jane.age
@@ -192,10 +192,10 @@ class UserAttr(property):
         prop_keys = ['yoke_specifier', 'alignment']
 
         for x in prop_keys:
-            if kwargs.has_key(x):
+            if x in kwargs:
                 setattr(self, '_'+x, kwargs[x])
         for x in direct_assign_keys:
-            if kwargs.has_key(x):
+            if x in kwargs:
                 setattr(self, x, kwargs[x])
 
     @property
@@ -366,20 +366,25 @@ class AttrNumeric:
         Decimal('0.04')
     """
     def __init__(self, prec):
-        assert prec>=0, "numeric precision must be at least zero"
-        self.prec=prec
+        assert prec >= 0, "numeric precision must be at least zero"
+        self.prec = prec
+        self.quant = decimal.Decimal(10)**-self.prec
+        self.quant_pre = decimal.Decimal(10)**-(self.prec+2)
 
     def __call__(self, value=None):
         if value in ["", None]:
-            return decimal.Decimal()._rescale(-self.prec,'ROUND_HALF_UP')
+            return decimal.Decimal().quantize(self.quant, 'ROUND_HALF_UP')
         elif type(value) in [float]:
-            # take higher precision when converting to a string
-            v = decimal.Decimal("%.*f" % (self.prec+2, value))
-            #print value, v
-            return v._rescale(-self.prec,'ROUND_HALF_UP')
+            # This pre-rounding is a little weird, but the mathematical fact is
+            # that (for example) round to 4 decimals followed by round to 2
+            # decimals is not the same as direct round to 2 decimals.  This
+            # logic is useful to compensate for imprecisions when a float
+            # literal is given as x.xx5 and user intuits that the 5 in the
+            # thousands will round up.
+            value = decimal.Decimal(value).quantize(self.quant_pre, 'ROUND_HALF_UP')
+            return value.quantize(self.quant, 'ROUND_HALF_UP')
         else:
-            v = decimal.Decimal(value)
-            return v._rescale(-self.prec,'ROUND_HALF_UP')
+            return decimal.Decimal(value).quantize(self.quant, 'ROUND_HALF_UP')
 
     @property
     def alignment(self):
