@@ -7,14 +7,14 @@
 ##############################################################################
 
 # Qt resource file
-import icons_rc
+from . import icons_rc
 
-from button_edit import PBButtonEdit
-from date_edit import PBDateEdit
-from key_edit import PBKeyEdit
+from .button_edit import PBButtonEdit
+from .date_edit import PBDateEdit
+from .key_edit import PBKeyEdit
 
-from table import TableView
-from tree import TreeView
+from .table import TableView
+from .tree import TreeView
 
-from street_address_widget import \
+from .street_address_widget import \
     StreetAddress, StreetAddressYoke, StreetAddressEdit, parse_address, concat_address
