@@ -11,13 +11,11 @@ The PBDateEdit provides a date input box with more flexible entry.
 It also supports null dates which is something QDateEdit does not.
 """
 
-from PySide import QtCore, QtGui
-from button_edit import PBButtonEdit, Property
 import datetime
-
 import fuzzyparsers
-
+from PySide import QtCore, QtGui
 from qtalchemy import fromQType, toQType
+from .button_edit import PBButtonEdit, Property
 
 class DateValidator(QtGui.QValidator):
     def __init__(self,parent=None):
@@ -31,14 +29,13 @@ class DateValidator(QtGui.QValidator):
         except:
             return ""
         #input.replace(0,input.length(),date.strftime("%x"))
-        print date.strftime("%x")
         return date.strftime("%x")
 
     def validate(self,input,pos):
         try:
             date = fuzzyparsers.parse_date(input)
             return QtGui.QValidator.Acceptable,input,pos
-        except Exception,e:
+        except Exception as e:
             return QtGui.QValidator.Intermediate,input,pos
     
 
