@@ -13,7 +13,7 @@ The PBKeyEdit provides data sensitive editting for foreign key edits::
 """
 
 from PySide import QtCore, QtGui
-from button_edit import PBButtonEdit
+from .button_edit import PBButtonEdit
 
 class PBKeyEdit(PBButtonEdit):
     """
