@@ -9,6 +9,6 @@
 This module contains tools to enable cross platform support.
 """
 
-from stderr import StdErrEater, guiexcepthook
+from .stderr import StdErrEater, guiexcepthook
 
-from util import is_windows, xdg_open
+from .util import is_windows, xdg_open
