@@ -22,7 +22,7 @@ def guiexcepthook(type, value, tb):
     >>> sys.excepthook = xplatform.guiexcepthook
     """
     try:
-        import util
+        from . import util
         import tempfile
         import traceback
         
